aboutsummaryrefslogtreecommitdiff
path: root/kernel/include/rpmsg/ethosu_rpmsg_inference.h
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/include/rpmsg/ethosu_rpmsg_inference.h')
-rw-r--r--kernel/include/rpmsg/ethosu_rpmsg_inference.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/kernel/include/rpmsg/ethosu_rpmsg_inference.h b/kernel/include/rpmsg/ethosu_rpmsg_inference.h
index 8bdfb8a..e1d1610 100644
--- a/kernel/include/rpmsg/ethosu_rpmsg_inference.h
+++ b/kernel/include/rpmsg/ethosu_rpmsg_inference.h
@@ -17,8 +17,8 @@
* http://www.gnu.org/licenses/gpl-2.0.html.
*/
-#ifndef ETHOSU_INFERENCE_H
-#define ETHOSU_INFERENCE_H
+#ifndef ETHOSU_RPMSG_INFERENCE_H
+#define ETHOSU_RPMSG_INFERENCE_H
/****************************************************************************
* Includes
@@ -35,13 +35,13 @@
****************************************************************************/
struct ethosu_buffer;
-struct ethosu_core_msg_inference_rsp;
-struct ethosu_network;
+struct ethosu_rpmsg_inference_rsp;
+struct ethosu_rpmsg_network;
struct ethosu_uapi_inference_create;
struct file;
/**
* struct ethosu_inference - Inference struct
* @edev: Arm Ethos-U device
* @file: File handle
* @kref: Reference counter
@@ -57,24 +57,24 @@ struct file;
* @pmu_cycle_counter_count: PMU cycle counter count after inference
* @msg: Mailbox message
*/
-struct ethosu_inference {
- struct device *dev;
- struct ethosu_mailbox *mailbox;
- struct file *file;
- struct kref kref;
- wait_queue_head_t waitq;
- bool done;
- uint32_t ifm_count;
- struct ethosu_buffer *ifm[ETHOSU_FD_MAX];
- uint32_t ofm_count;
- struct ethosu_buffer *ofm[ETHOSU_FD_MAX];
- struct ethosu_network *net;
- enum ethosu_uapi_status status;
- uint8_t pmu_event_config[ETHOSU_PMU_EVENT_MAX];
- uint64_t pmu_event_count[ETHOSU_PMU_EVENT_MAX];
- uint32_t pmu_cycle_counter_enable;
- uint64_t pmu_cycle_counter_count;
- struct ethosu_mailbox_msg msg;
+struct ethosu_rpmsg_inference {
+ struct device *dev;
+ struct ethosu_rpmsg_mailbox *mailbox;
+ struct file *file;
+ struct kref kref;
+ wait_queue_head_t waitq;
+ bool done;
+ uint32_t ifm_count;
+ struct ethosu_buffer *ifm[ETHOSU_FD_MAX];
+ uint32_t ofm_count;
+ struct ethosu_buffer *ofm[ETHOSU_FD_MAX];
+ struct ethosu_rpmsg_network *net;
+ enum ethosu_uapi_status status;
+ uint8_t pmu_event_config[ETHOSU_PMU_EVENT_MAX];
+ uint64_t pmu_event_count[ETHOSU_PMU_EVENT_MAX];
+ uint32_t pmu_cycle_counter_enable;
+ uint64_t pmu_cycle_counter_count;
+ struct ethosu_rpmsg_mailbox_msg msg;
};
/****************************************************************************
@@ -82,43 +82,43 @@ struct ethosu_inference {
****************************************************************************/
/**
- * ethosu_inference_create() - Create inference
+ * ethosu_rpmsg_inference_create() - Create inference
*
* This function must be called in the context of a user space process.
*
* Return: fd on success, else error code.
*/
-int ethosu_inference_create(struct device *dev,
- struct ethosu_mailbox *mailbox,
- struct ethosu_network *net,
- struct ethosu_uapi_inference_create *uapi);
+int ethosu_rpmsg_inference_create(struct device *dev,
+ struct ethosu_rpmsg_mailbox *mailbox,
+ struct ethosu_rpmsg_network *net,
+ struct ethosu_uapi_inference_create *uapi);
/**
* ethosu_inference_get_from_fd() - Get inference handle from fd
*
* This function must be called from a user space context.
*
* Return: Pointer on success, else ERR_PTR.
*/
-struct ethosu_inference *ethosu_inference_get_from_fd(int fd);
+struct ethosu_rpmsg_inference *ethosu_rpmsg_inference_get_from_fd(int fd);
/**
- * ethosu_inference_get() - Get inference
+ * ethosu_rpmsg_inference_get() - Get inference
*/
-void ethosu_inference_get(struct ethosu_inference *inf);
+void ethosu_rpmsg_inference_get(struct ethosu_rpmsg_inference *inf);
/**
- * ethosu_inference_put() - Put inference
+ * ethosu_rpmsg_inference_put() - Put inference
*
* Return: 1 if object was removed, else 0.
*/
-int ethosu_inference_put(struct ethosu_inference *inf);
+int ethosu_rpmsg_inference_put(struct ethosu_rpmsg_inference *inf);
/**
* ethosu_inference_rsp() - Handle inference response
*/
-void ethosu_inference_rsp(struct ethosu_mailbox *mailbox,
- int msg_id,
- struct ethosu_core_msg_inference_rsp *rsp);
+void ethosu_rpmsg_inference_rsp(struct ethosu_rpmsg_mailbox *mailbox,
+ int msg_id,
+ struct ethosu_rpmsg_inference_rsp *rsp);
-#endif /* ETHOSU_INFERENCE_H */
+#endif /* ETHOSU_RPMSG_INFERENCE_H */
@@ -35,13 +35,13 @@
struct file;
/**
- * struct ethosu_inference - Inference struct
+ * struct ethosu_rpmsg_inference - Inference struct
* @edev: Arm Ethos-U device
* @file: File handle
@@ -82,43 +82,43 @@ struct ethosu_inference {
/**
- * ethosu_inference_get_from_fd() - Get inference handle from fd
+ * ethosu_rpmsg_inference_get_from_fd() - Get inference handle from fd
*
* This function must be called from a user space context.
@@ -82,43 +82,43 @@ struct ethosu_inference {
/**
- * ethosu_inference_rsp() - Handle inference response
+ * ethosu_rpmsg_inference_rsp() - Handle inference response
*/